//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using LidorSystems.IntegralUI.Lists;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Variables
        private int[] randomInts = new int[] { 1, 2, 0, 4, 5, 3, 2, 0, 1 };
        private int nodeCount = 0;
        private bool expanded = false;
        #endregion

        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   In this sample we are demonstrating how to expand nodes vertically in upward, downward or in both directions.</p><br></br>";
            content += "<p>   By default each node expands in a way that all child nodes are shown below its parent node. If you select the <b>Up</b> option from control panel, you will notice that each child node now is displayed above its parent node.</p><br></br>";
            content += "<p>   Further more there are cases when you need to display child nodes in both directions, to see how this works select the <b>Both</b> option from control panel.</p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void InitList()
        {
            this.treeView1.SuspendUpdate();
            this.treeView1.Nodes.Clear();

            nodeCount = 0;

            CreateNode(this.treeView1.RootNode, "", 0);

            this.treeView1.ResumeUpdate();
        }

        private void CreateNode(LidorSystems.IntegralUI.Lists.TreeNode parentNode, String prefix, int level)
        {
            if (level == 5)
                return;

            int limit = randomInts[nodeCount % 9];
            if (level == 0)
                limit = 10;

            LidorSystems.IntegralUI.Lists.TreeNode node = null;
            for (int i = 1; i <= limit; i++)
            {
                node = new LidorSystems.IntegralUI.Lists.TreeNode("Node " + prefix + i.ToString());
                if (rbDown.Checked)
                    node.DisplayPosition = TreeNodeDisplayPosition.Below;
                else if (rbUp.Checked)
                    node.DisplayPosition = TreeNodeDisplayPosition.Above;
                else
                {
                    if (nodeCount % 2 == 0)
                        node.DisplayPosition = TreeNodeDisplayPosition.Above;
                }


                parentNode.Nodes.Add(node);
                nodeCount++;

                CreateNode(node, prefix + i.ToString(), level + 1);
            }
        }
        #endregion

        #region Update
        private void btnUpdate_Click(object sender, EventArgs e)
        {
            InitList();

            expanded = false;
            this.btnToggle.Text = "Expand All";
        }

        private void btnToggle_Click(object sender, EventArgs e)
        {
            if (expanded)
            {
                this.treeView1.CollapseAll();
                this.btnToggle.Text = "Expand All";
            }
            else
            {
                this.treeView1.ExpandAll();
                this.btnToggle.Text = "Collapse All";
            }

            expanded = !expanded;
        }
        #endregion
    }
}